@@ -22,7 +22,7 @@
 
 #define u32 __u32
 #define __DEBUG__ 0
-#define VERSION "1.4"
+#define VERSION "1.6"
 
 int wminet_mask_width = 16;
 int wminet_mask_height = 16;
@@ -49,8 +49,6 @@ void updateHistory(char *);
 void writeHistory(void);
 
 void callback(GtkWidget *, gpointer);
-void keypress(GtkWidget *, GdkEventKey *, gpointer);
-gint delete_event(GtkWidget *, GdkEvent *, gpointer);
 void usage(void);
 
 /********************************
@@ -258,7 +256,7 @@ void updateHistory(char *newHistoryItem)
       fprintf(stderr, " duplicate of item [%02d].\n", duplicate);
 
     if (duplicate != (historyLength - 1)) {	// If the duplicate entry is not at the end 
-      histTransit = *(histTOC + duplicate);
+      histTransit = (u32 *) (histTOC + duplicate);
 
       // Shift each entry forward
       for (historyIndex = duplicate; historyIndex < historyLength - 1; historyIndex++) {
@@ -330,18 +328,6 @@ void callback (GtkWidget * widget, gpointer data)
   gtk_main_quit();
 }
 
-// Event handler for Enter and Escape keys
-void keypress(GtkWidget *widget, GdkEventKey *event, gpointer data) 
-{
-  if (event->keyval == GDK_Return) {
-    execDialogInformation();
-    gtk_main_quit();
-    gtk_object_destroy(GTK_OBJECT(widget));
-  } else if (event->keyval == GDK_Escape) {
-    gtk_main_quit();
-    gtk_object_destroy(GTK_OBJECT(widget));
-  }
-}
 
 // This handles executing the information in the dialog box when the user hits 'ok'
 void execDialogInformation() 
@@ -351,7 +337,7 @@ void execDialogInformation()
   char backgroundCommand[MAXCMDLEN + 3];
   char *originalWorkingDirectory = '\0';
 
-  command = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry));
+  command = (gchar *) gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo)->entry));
   if (command[0] != '\0') {
     bzero(backgroundCommand, MAXPATHLEN + 3);
     if (__DEBUG__)
@@ -362,7 +348,7 @@ void execDialogInformation()
     strcat(backgroundCommand, " &");
     if (advancedMode) {
       originalWorkingDirectory = getcwd(NULL, 0);
-      workingPath = gtk_entry_get_text(GTK_ENTRY(workingDirectoryEntry));
+      workingPath = (gchar *) gtk_entry_get_text(GTK_ENTRY(workingDirectoryEntry));
       if (__DEBUG__) {
         fprintf(stderr, "Original working directory is '%s'\n", originalWorkingDirectory);
         fprintf(stderr, "Execution working path is '%s'\n", workingPath);
@@ -385,13 +371,18 @@ void execDialogInformation()
   }
 }
 
-/* another callback */
-gint delete_event(GtkWidget * widget, GdkEvent * event, gpointer data) 
-{
-  gtk_main_quit();
-  return (FALSE);
+
+gboolean key_pressed(GtkWidget *widget, GdkEventKey *event) {
+  if(widget && event && event->keyval == GDK_Escape) {
+    gtk_widget_destroy(widget);
+    gtk_main_quit();
+  }
+  
+  return FALSE;
 }
 
+
+
 int runwin()
 {
   GtkWidget *window;
@@ -408,17 +399,12 @@ int runwin()
   gtk_window_set_title(GTK_WINDOW (window), "Run");
   gtk_container_set_border_width(GTK_CONTAINER(window), 10); 	// Sets the border width of the window
 
-  // Here we just set a handler for delete_event that immediately exits GTK.
-  gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(delete_event), NULL);
-
-  // Handle the enter and escape keys.
-  gtk_signal_connect(GTK_OBJECT(window), "key-press-event", GTK_SIGNAL_FUNC(keypress), GTK_OBJECT(window));
 
   // Create a text entry area with drop down history list
   combo = gtk_combo_new();
   gtk_widget_set_usize(combo, 300, 30);
   gtk_combo_set_use_arrows_always(GTK_COMBO(combo), TRUE); 	// scroll through the list with the arrow keys.
-  gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry), "activate", GTK_SIGNAL_FUNC(callback), NULL);
+  gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry), "activate", GTK_SIGNAL_FUNC(callback), "ok");
   gtk_window_set_focus(GTK_WINDOW(window), GTK_COMBO(combo)->entry); // focus the entry area so we can type right away.
 
   // Instead of appending the items in reverse order, we prepend each item.
@@ -497,9 +483,15 @@ int runwin()
   gtk_widget_show(table);
   gtk_widget_show(window);
 
+  g_signal_connect(G_OBJECT(window), "key_press_event", G_CALLBACK(key_pressed), NULL);
+  g_signal_connect (GTK_OBJECT(window), "destroy", G_CALLBACK (gtk_main_quit), NULL);
+
+  GTK_WIDGET_SET_FLAGS (okButton, GTK_CAN_DEFAULT);
+  gtk_widget_grab_default (okButton);
+
   gtk_main();					// Rest in gtk_main and wait for the fun to begin!
 
-  return (0);
+  return 0;
 }
 
 void usage (void) 
